====================
django-shortcuts-ext
====================

Django Shortcuts Extensions

Installation
============

::

    pip install django-shortcuts-ext


Usage
=====

::

    from django_shortcuts_ext import json_render, cookie_render, cookie_redirect

